pub fn bpf_size(filter: &sock_filter) -> u8Expand description
The bpf_size is the 4th and 5th bit of load and store instructions. It indicates the bit width of the load / store target (8, 16, 32, 64 bits).
pub fn bpf_size(filter: &sock_filter) -> u8The bpf_size is the 4th and 5th bit of load and store instructions. It indicates the bit width of the load / store target (8, 16, 32, 64 bits).