EbpfPtr

Struct EbpfPtr 

pub struct EbpfPtr<'a, T> { /* private fields */ }
Pointer to a buffer that may be shared between eBPF programs. It allows to safely pass around pointers to the data stored in eBPF maps and access the data referenced by the pointer.

Implementations

Source

impl<'a, T> EbpfPtr<'a, T>
where T: Sized,

pub unsafe fn new(ptr: *mut T) -> Self

Creates a new EbpfPtr from the specified pointer.

Safety

Caller must ensure that the buffer referenced by ptr is valid for lifetime 'a and there are no other mutable references to the same memory.

pub unsafe fn deref(&self) -> &'a T

Safety

Caller must ensure that the value cannot be updated by other threads while the returned reference is live.

pub unsafe fn deref_mut(&self) -> &'a mut T

Safety

Caller must ensure that the value is not being used by other threads.

pub fn get_field<F, const OFFSET: usize>(&self) -> EbpfPtr<'a, F>

pub fn ptr(&self) -> *mut T

Source

impl EbpfPtr<'_, u64>

pub fn load_relaxed(&self) -> u64

Loads the value referenced by the pointer. Atomicity is guaranteed if and only if the pointer is 8-byte aligned.

pub fn store_relaxed(&self, value: u64)

Stores the value at the memory referenced by the pointer. Atomicity is guaranteed if and only if the pointer is 8-byte aligned.

Source

impl EbpfPtr<'_, u32>

pub fn load_relaxed(&self) -> u32

Loads the value referenced by the pointer. Atomicity is guaranteed if and only if the pointer is 4-byte aligned.

pub fn store_relaxed(&self, value: u32)

Stores the value at the memory referenced by the pointer. Atomicity is guaranteed if and only if the pointer is 4-byte aligned.

Source

impl EbpfPtr<'_, i32>

pub fn load_relaxed(&self) -> i32

Loads the value referenced by the pointer. Atomicity is guaranteed if and only if the pointer is 4-byte aligned.

pub fn store_relaxed(&self, value: i32)

Stores the value at the memory referenced by the pointer. Atomicity is guaranteed if and only if the pointer is 4-byte aligned.