pub enum Namespace {
Hardcoded,
Generated,
Verification,
}Expand description
An identifier for a memory buffer accessible by an ebpf program. The identifiers are built as a
chain of unique identifier so that a buffer can contain multiple pointers to the same type and
the verifier can distinguish between the different instances.
The namespace of a MemoryId, used to prevent collisions between different
sources of identifiers.
Variants
Hardcoded
For static structure identifiers (e.g., SkBuff, BpfSock) defined in program_type.rs.
Generated
For IDs generated by MemoryId::new() using the global counter.
Verification
For IDs generated by VerificationContext::next_id() using the local counter.